@@ -11,7 +11,7 @@
 #                                                                                                                      #
 # License:                                                                                                             #
 # ==================================================================================================================== #
-# Copyright 2017-2021 Patrick Lehmann - Bötzingen, Germany                                                             #
+# Copyright 2017-2022 Patrick Lehmann - Bötzingen, Germany                                                             #
 #                                                                                                                      #
 # Licensed under the Apache License, Version 2.0 (the "License");                                                      #
 # you may not use this file except in compliance with the License.                                                     #
@@ -31,9 +31,9 @@
 """A set of helpers to implement a text user interface (TUI) in a terminal."""
 __author__ =    "Patrick Lehmann"
 __email__ =     "Paebbels@gmail.com"
-__copyright__ = "2007-2021, Patrick Lehmann"
+__copyright__ = "2007-2022, Patrick Lehmann"
 __license__ =   "Apache License, Version 2.0"
-__version__ =   "1.5.6"
+__version__ =   "1.5.9"
 __keywords__ =  ["terminal", "shell", "text user interface", "TUI", "console", "message logging"]
 
 from enum                   import Enum, unique
@@ -41,7 +41,7 @@ from platform               import system as platform_system
 from typing                 import NoReturn, Tuple, Any
 
 from pyTooling.Decorators   import export
-from pyTooling.MetaClasses  import Singleton
+from pyTooling.MetaClasses  import ExtendedType
 
 
 @export
@@ -97,7 +97,7 @@ class Terminal:
 	_width  : int = None      #: Terminal width in characters
 	_height : int = None      #: Terminal height in characters
 
-	def __init__(self) -> None:
+	def __init__(self):
 		"""
 		Initialize a terminal.
 
@@ -390,7 +390,7 @@ class Line:
 		Severity.DryRun:    "DRYRUN: {message}"
 	}                     #: Terminal messages formatting rules
 
-	def __init__(self, message, severity=Severity.Normal, indent=0, appendLinebreak=True) -> None:
+	def __init__(self, message, severity=Severity.Normal, indent=0, appendLinebreak=True):
 		"""Constructor for a new ``Line`` object."""
 		self._severity =        severity
 		self._message =         message
@@ -428,7 +428,7 @@ class ILineTerminal:
 
 	_terminal = None
 
-	def __init__(self, terminal=None) -> None:
+	def __init__(self, terminal=None):
 		"""MixIn initializer."""
 		self._terminal = terminal
 
@@ -506,8 +506,8 @@ class ILineTerminal:
 
 
 @export
-class LineTerminal(Terminal, ILineTerminal, metaclass=Singleton):
-	def __init__(self, verbose=False, debug=False, quiet=False, writeToStdOut=True) -> None:
+class LineTerminal(Terminal, ILineTerminal, metaclass=ExtendedType, singleton=True):
+	def __init__(self, verbose=False, debug=False, quiet=False, writeToStdOut=True):
 		"""Initializer of a line based terminal interface."""
 		Terminal.__init__(self)
 		ILineTerminal.__init__(self, self)
